Tango/DOOCS/Tine/Epics Image Source Settings — LaVue 2.76.0 documentation

# Tango/DOOCS/Tine/Epics Image Source Settings

The fourth tab of the configuration dialog contains Image Sources configuration. It allows for the user to adjust image sources and their dialogs.

Tango Attribute

- Attributes: JSON dictionary assigning labels to image TANGO device attributes

Tango Events

- Attributes: JSON dictionary assigning labels to image TANGO device attributes

Tango File

- File Attributes: JSON dictionary assigning labels to file TANGO device attributes

- Dir Attributes: JSON dictionary assigning labels to directory TANGO device attributes

- File/Dir translation: JSON dictionary translating file path and file names.
  It can be useful when files are automatically copied from detector PC to other location.

DOOCS Property

- Properties: JSON dictionary assigning labels to image DOOCS device properties

Tine Property

- Properties: JSON dictionary assigning labels to image Tine device properties

Epics PV

- PV Names: JSON dictionary assigning labels to image Epics device process variables

- PV Shapes: JSON dictionary assigning labels to image Epics device process variable shapes